@@ -1173,7 +1173,8 @@ class Assignment(Base):
 
     # Код контекста
     # Имеет в основном вид "course_26939", "course_24569" и т.д.
-    context_code = Column(String(255))
+    # TODO: context_code отсутствует у ino.yu.edu.kz. Необходимо решить эту проблему
+    # context_code = Column(String(255))
 
     # Позиция в списке
     # Показывает порядок позиции в списке, чем меньше значение тем выше он находится
